pub(crate) enum ImplSource<'db, N> {
UserDefined(ImplSourceUserDefinedData<'db, N>),
Param(Vec<N>),
Builtin(BuiltinImplSource, Vec<N>),
}Expand description
Given the successful resolution of an obligation, the ImplSource
indicates where the impl comes from.
For example, the obligation may be satisfied by a specific impl (case A), or it may be relative to some bound that is in scope (case B).
ⓘ
impl<T:Clone> Clone<T> for Option<T> { ... } // Impl_1
impl<T:Clone> Clone<T> for Box<T> { ... } // Impl_2
impl Clone for i32 { ... } // Impl_3
fn foo<T: Clone>(concrete: Option<Box<i32>>, param: T, mixed: Option<T>) {
// Case A: ImplSource points at a specific impl. Only possible when
// type is concretely known. If the impl itself has bounded
// type parameters, ImplSource will carry resolutions for those as well:
concrete.clone(); // ImplSource(Impl_1, [ImplSource(Impl_2, [ImplSource(Impl_3)])])
// Case B: ImplSource must be provided by caller. This applies when
// type is a type parameter.
param.clone(); // ImplSource::Param
// Case C: A mix of cases A and B.
mixed.clone(); // ImplSource(Impl_1, [ImplSource::Param])
}The type parameter N
See explanation on ImplSourceUserDefinedData.
Variants
UserDefined(ImplSourceUserDefinedData<'db, N>)
ImplSource identifying a particular impl.
Param(Vec<N>)
Successful resolution to an obligation provided by the caller
for some type parameter. The Vec<N> represents the
obligations incurred from normalizing the where-clause (if
any).
Builtin(BuiltinImplSource, Vec<N>)
Successful resolution for a builtin impl.
Implementations
Sourceimpl<'db, N> ImplSource<'db, N>
impl<'db, N> ImplSource<'db, N>
pub(crate) fn nested_obligations(self) -> Vec<N>
pub(crate) fn borrow_nested_obligations(&self) -> &[N]
pub(crate) fn borrow_nested_obligations_mut(&mut self) -> &mut [N]
pub(crate) fn map<M, F>(self, f: F) -> ImplSource<'db, M>where
F: FnMut(N) -> M,