SelectionResult

Type Alias SelectionResult 

pub(crate) type SelectionResult<'db, T> = Result<Option<T>, SelectionError<'db>>;
When performing resolution, it is typically the case that there can be one of three outcomes:

  • Ok(Some(r)): success occurred with result r
  • Ok(None): could not definitely determine anything, usually due to inconclusive type inference.
  • Err(e): error e occurred

Aliased Type

pub(crate) enum SelectionResult<'db, T> {
    Ok(Option<T>),
    Err(SelectionError<'db>),
}

Variants

1.0.0

Ok(Option<T>)

Contains the success value

1.0.0

Err(SelectionError<'db>)

Contains the error value