pub(crate) type SelectionResult<'db, T> = Result<Option<T>, SelectionError<'db>>;Expand description
When performing resolution, it is typically the case that there can be one of three outcomes:
Ok(Some(r)): success occurred with resultrOk(None): could not definitely determine anything, usually due to inconclusive type inference.Err(e): erroreoccurred
Aliased Type
pub(crate) enum SelectionResult<'db, T> {
Ok(Option<T>),
Err(SelectionError<'db>),
}Variants
Ok(Option<T>)
Contains the success value
Err(SelectionError<'db>)
Contains the error value